/**
 * 教育背景
 */

export default {
  id: 'application_info_education',
  title: '教育背景',
  required: true,
  get: {
    action: '/api/enrollment/v1.0/application-materials/1005',
    callback(data) {
      const { educations = [] } = data.data.material
      return educations.map(item => {
        const { start_date: startDate, end_date: endDate } = item
        if (startDate) {
          item.dates = [startDate, endDate]
        }
        return item
      })
    }
  },
  update: {
    action: '/api/enrollment/v1.0/application-materials/1005/put',
    beforeRequest(data) {
      const educations = data.map(item => {
        const [startDate, endDate] = item.dates
        item.start_date = startDate
        item.end_date = endDate
        return [
          'start_date',
          'end_date',
          'school_name_cn',
          'school_country',
          'school_city',
          'major_cn',
          'degree'
        ].reduce((result, key) => {
          result[key] = item[key]
          return result
        }, {})
      })
      return { educations }
    }
  },
  form: {
    hasAdd: true,
    options: {
      labelWidth: '140px'
    },
    items: [
      {
        type: 'v-datepicker',
        label: '教育时间',
        model: 'dates',
        attrs: {
          type: 'monthrange',
          rangeSeparator: '至',
          startPlaceholder: '请选择开始时间',
          endPlaceholder: '请选择结束时间',
          valueFormat: 'yyyyMM'
        },
        rules: [{ required: true, message: '请选择教育时间', trigger: 'blur' }]
      },
      {
        type: 'v-input',
        label: '学校名称',
        model: 'school_name_cn',
        rules: [{ required: true, message: '请输入学校名称', trigger: 'blur' }]
      },
      {
        type: 'v-input',
        label: '专业名称',
        model: 'major_cn',
        rules: [{ required: true, message: '请输入专业名称', trigger: 'blur' }]
      },
      {
        type: 'v-select',
        values: [
          { value: '专科' },
          { value: '本科' },
          { value: '本科/学士' },
          { value: '硕士研究生' },
          { value: '研究生/硕士' },
          { value: '博士研究生' },
          { value: '研究生/博士' },
          { value: '其他' }
        ],
        label: '学历/学位',
        model: 'degree',
        rules: [{ required: true, message: '请选择学历/学位', trigger: 'change' }]
      }
    ]
  }
}
