/**
 * 个人信息
 */

export default {
  id: 'application_info_first',
  title: '个人信息',
  required: true,
  get: {
    action: '/api/enrollment/v1.0/application-materials/1005',
    callback(data) {
      const { basic_info: basicInfo = {}, attachments = [] } = data.data.material
      const attachment = attachments.reduce(
        (result, item) => {
          const types = ['ID_CARD_FRONT', 'ID_CARD_BACK', 'HK_ID_CARD', 'PASSPORT', 'OTHER_ID_CARD_PHOTO']
          types.forEach(type => {
            if (item.file_type_id === type) {
              result[type].push(item)
            }
          })
          return result
        },
        { ID_CARD_FRONT: [], ID_CARD_BACK: [], HK_ID_CARD: [], PASSPORT: [], OTHER_ID_CARD_PHOTO: [] }
      )
      return Object.assign({}, { basic_info: basicInfo }, attachment)
    }
  },
  update: {
    action: '/api/enrollment/v1.0/application-materials/1005/put',
    beforeRequest(data) {
      const basicInfo = ['phone_number', 'email', 'id_type'].reduce((result, key) => {
        result[key] = data[key]
        return result
      }, {})
      return { basic_info: basicInfo }
    }
  },
  form: {
    // hasButton: false,
    options: {
      labelWidth: '140px'
    },
    items: [
      {
        type: 'v-input',
        label: '手机号',
        model: 'phone_number',
        attrs: { placeholder: '请输入手机号' },
        rules: [{ required: true, message: '请输入手机号', trigger: 'blur' }]
      },
      {
        type: 'v-input',
        label: '邮箱',
        model: 'email',
        attrs: { placeholder: '请输入邮箱' },
        rules: [{ required: true, message: '请输入邮箱', trigger: 'blur' }]
      },
      {
        type: 'v-select',
        values: [{ value: '居民身份证' }, { value: '港澳台身份证' }, { value: '护照' }, { value: '其他' }],
        label: '证件类型',
        model: 'id_type',
        attrs: { placeholder: '请选择证件类型' },
        rules: [{ required: true, message: '请选择证件类型', trigger: 'change' }]
      },
      // 身份证照片(正面）
      {
        type: 'v-upload',
        label: '身份证照片(正面)',
        model: 'ID_CARD_FRONT',
        attrs: {
          action: '/api/enrollment/v1.0/application-materials/attachments/1005/put',
          deleteAction: '/api/enrollment/v1.0/application-materials/attachments/1005/delete',
          data: { file_type: 'ID_CARD_FRONT' },
          limit: 1
        },
        rules: [{ type: 'array', required: true, message: '请上传身份证照片(正面)', trigger: 'change' }],
        isShow(data) {
          return data.id_type === '居民身份证'
        }
      },
      // 身份证照片(背面)
      {
        type: 'v-upload',
        label: '身份证照片(背面)',
        model: 'ID_CARD_BACK',
        attrs: {
          action: '/api/enrollment/v1.0/application-materials/attachments/1005/put',
          deleteAction: '/api/enrollment/v1.0/application-materials/attachments/1005/delete',
          data: { file_type: 'ID_CARD_BACK' },
          limit: 1
        },
        rules: [{ type: 'array', required: true, message: '请上传身份证照片(背面)', trigger: 'change' }],
        isShow(data) {
          return data.id_type === '居民身份证'
        }
      },
      // 港澳台身份证
      {
        type: 'v-upload',
        label: '港澳台身份证',
        model: 'HK_ID_CARD',
        attrs: {
          action: '/api/enrollment/v1.0/application-materials/attachments/1005/put',
          deleteAction: '/api/enrollment/v1.0/application-materials/attachments/1005/delete',
          data: { file_type: 'HK_ID_CARD' },
          limit: 1
        },
        rules: [{ type: 'array', required: true, message: '请上传港澳台身份证', trigger: 'change' }],
        isShow(data) {
          return data.id_type === '港澳台身份证'
        }
      },
      // 护照
      {
        type: 'v-upload',
        label: '护照',
        model: 'PASSPORT',
        attrs: {
          action: '/api/enrollment/v1.0/application-materials/attachments/1005/put',
          deleteAction: '/api/enrollment/v1.0/application-materials/attachments/1005/delete',
          data: { file_type: 'PASSPORT' },
          limit: 1
        },
        rules: [{ type: 'array', required: true, message: '请上传护照', trigger: 'change' }],
        isShow(data) {
          return data.id_type === '护照'
        }
      },
      // 其他证件
      {
        type: 'v-upload',
        label: '其他证件',
        model: 'OTHER_ID_CARD_PHOTO',
        attrs: {
          action: '/api/enrollment/v1.0/application-materials/attachments/1005/put',
          deleteAction: '/api/enrollment/v1.0/application-materials/attachments/1005/delete',
          data: { file_type: 'OTHER_ID_CARD_PHOTO' },
          limit: 1
        },
        rules: [{ type: 'array', required: true, message: '请上传其他证件', trigger: 'change' }],
        isShow(data) {
          return data.id_type === '其他'
        }
      }
    ]
  }
}
